Market Endpoints
================

Test Connectivity
-----------------
.. autofunction:: binance.spot.Spot.ping

Check Server Time
-----------------
.. autofunction:: binance.spot.Spot.time

Exchange Information
--------------------
.. autofunction:: binance.spot.Spot.exchange_info

Get orderbook
-------------
.. autofunction:: binance.spot.Spot.depth

Recent Trades List
------------------
.. autofunction:: binance.spot.Spot.trades

Old Trade Lookup
----------------
.. autofunction:: binance.spot.Spot.historical_trades

Compressed/Aggregate Trades List
--------------------------------
.. autofunction:: binance.spot.Spot.agg_trades

Kline/Candlestick Data
----------------------
.. autofunction:: binance.spot.Spot.klines

UIKlines
--------
.. autofunction:: binance.spot.Spot.ui_klines

Current Average Price
---------------------
.. autofunction:: binance.spot.Spot.avg_price

24hr Ticker Price Change Statistics
-----------------------------------
.. autofunction:: binance.spot.Spot.ticker_24hr

Trading Day Ticker
------------------
.. autofunction:: binance.spot.Spot.trading_day_ticker

Symbol Price Ticker
-------------------
.. autofunction:: binance.spot.Spot.ticker_price

Symbol Order Book Ticker
------------------------
.. autofunction:: binance.spot.Spot.book_ticker

Rolling window price change statistics
--------------------------------------
.. autofunction:: binance.spot.Spot.rolling_window_ticker
